@@ -1,4 +1,4 @@
-from .enums import StreamType  # noqa
+from .enums import StreamState, StreamType  # noqa
 from .grand_composite_curve import GrandCompositeCurve  # noqa
 from .line import extract_x, y_range  # noqa
 from .pinch_analyzer import PinchAnalyzer  # noqa
